==> uppy__compressor-1.0.1.jar: META-INF/resources/webjars/uppy__compressor/1.0.1/CHANGELOG.md <==
# @uppy/compressor

## 1.0.1

Released: 2022-09-25
Included in: Uppy v3.1.0

- @uppy/audio,@uppy/aws-s3-multipart,@uppy/aws-s3,@uppy/box,@uppy/companion-client,@uppy/companion,@uppy/compressor,@uppy/core,@uppy/dashboard,@uppy/drag-drop,@uppy/drop-target,@uppy/dropbox,@uppy/facebook,@uppy/file-input,@uppy/form,@uppy/golden-retriever,@uppy/google-drive,@uppy/image-editor,@uppy/informer,@uppy/instagram,@uppy/locales,@uppy/onedrive,@uppy/progress-bar,@uppy/provider-views,@uppy/react,@uppy/redux-dev-tools,@uppy/remote-sources,@uppy/screen-capture,@uppy/status-bar,@uppy/store-default,@uppy/store-redux,@uppy/svelte,@uppy/thumbnail-generator,@uppy/transloadit,@uppy/tus,@uppy/unsplash,@uppy/url,@uppy/utils,@uppy/vue,@uppy/webcam,@uppy/xhr-upload,@uppy/zoom: add missing entries to changelog for individual packages (Antoine du Hamel / #4092)

## 1.0.0

Released: 2022-08-22
Included in: Uppy v3.0.0

- Switch to ESM

## 1.0.0-beta.3

Released: 2022-08-16
Included in: Uppy v3.0.0-beta.5

- @uppy/compressor: Fix Compressor being broken when no name is in the compressed blob (Artur Paikin / #3947)

## 0.3.1

Released: 2022-07-27
Included in: Uppy v2.13.1

- @uppy/compressor: fix upload causing meta name to reset (Justin / #3890)

## 0.3.0

Released: 2022-05-30
Included in: Uppy v2.11.0

- @uppy/compressor: Fix Compressor docs, pass files array to compressor:complete event (Artur Paikin / #3682)

## 0.2.5

Released: 2022-04-27
Included in: Uppy v2.9.4

- @uppy/compressor: Set meta on file compression (Camilo Forero / #3644)

## 0.2.4

Released: 2022-04-07
Included in: Uppy v2.9.2

- @uppy/compressor: Merge new name and type into compressed file (Camilo Forero / #3606)

## 0.2.3

Released: 2022-03-16
Included in: Uppy v2.8.0

- @uppy/compressor: ignore remote files, calculate savings correctly (Artur Paikin / #3578)

## 0.2.2

Released: 2022-02-16
Included in: Uppy v2.5.1

- @uppy/compressor: Add image compressor plugin (Artur Paikin / #3471)

==> uppy__compressor-1.0.4.jar: META-INF/resources/webjars/uppy__compressor/1.0.4/CHANGELOG.md <==
# @uppy/compressor

## 1.0.3

Released: 2023-09-18
Included in: Uppy v3.16.0

- @uppy/compressor: update file.meta.name after compression, becase format/extension might have changed (Artur Paikin / #4645)

## 1.0.1

Released: 2022-09-25
Included in: Uppy v3.1.0

- @uppy/audio,@uppy/aws-s3-multipart,@uppy/aws-s3,@uppy/box,@uppy/companion-client,@uppy/companion,@uppy/compressor,@uppy/core,@uppy/dashboard,@uppy/drag-drop,@uppy/drop-target,@uppy/dropbox,@uppy/facebook,@uppy/file-input,@uppy/form,@uppy/golden-retriever,@uppy/google-drive,@uppy/image-editor,@uppy/informer,@uppy/instagram,@uppy/locales,@uppy/onedrive,@uppy/progress-bar,@uppy/provider-views,@uppy/react,@uppy/redux-dev-tools,@uppy/remote-sources,@uppy/screen-capture,@uppy/status-bar,@uppy/store-default,@uppy/store-redux,@uppy/svelte,@uppy/thumbnail-generator,@uppy/transloadit,@uppy/tus,@uppy/unsplash,@uppy/url,@uppy/utils,@uppy/vue,@uppy/webcam,@uppy/xhr-upload,@uppy/zoom: add missing entries to changelog for individual packages (Antoine du Hamel / #4092)

## 1.0.0

Released: 2022-08-22
Included in: Uppy v3.0.0

- Switch to ESM

## 1.0.0-beta.3

Released: 2022-08-16
Included in: Uppy v3.0.0-beta.5

- @uppy/compressor: Fix Compressor being broken when no name is in the compressed blob (Artur Paikin / #3947)

## 0.3.1

Released: 2022-07-27
Included in: Uppy v2.13.1

- @uppy/compressor: fix upload causing meta name to reset (Justin / #3890)

## 0.3.0

Released: 2022-05-30
Included in: Uppy v2.11.0

- @uppy/compressor: Fix Compressor docs, pass files array to compressor:complete event (Artur Paikin / #3682)

## 0.2.5

Released: 2022-04-27
Included in: Uppy v2.9.4

- @uppy/compressor: Set meta on file compression (Camilo Forero / #3644)

## 0.2.4

Released: 2022-04-07
Included in: Uppy v2.9.2

- @uppy/compressor: Merge new name and type into compressed file (Camilo Forero / #3606)

## 0.2.3

Released: 2022-03-16
Included in: Uppy v2.8.0

- @uppy/compressor: ignore remote files, calculate savings correctly (Artur Paikin / #3578)

## 0.2.2

Released: 2022-02-16
Included in: Uppy v2.5.1

- @uppy/compressor: Add image compressor plugin (Artur Paikin / #3471)
